==> rsp-drl-0.0.12.tar.gz: rsp-drl-0.0.12/setup.py <==
from setuptools import setup, find_packages

VERSION = '0.0.12' 
DESCRIPTION = 'Some basic functionalities'
with open('README.md') as f:
    LONG_DESCRIPTION = f.read()

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="rsp-drl", 
        version=VERSION,
        author="Robert Schulz",
        author_email="schulzr256@gmail.com",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        long_description_content_type='text/markdown',
        package_dir={"rsp": "rsp"},
        include_package_data=True,
        package_data={
            "": ["*.png"],
            "package_data": ["*.*", "*/*.*", "*/*/*.*"],
            "rsp": ["data/*.*", "data/*/*.*"]
        },
        license="MIT",
        packages=find_packages(),
        install_requires=[
            'torch',
            'torchvision',
            'torchaudio',
            'rsp-common',
            'numpy',
            'opencv-python',
            'gym'
        ], # add any additional packages that 
        # needs to be installed along with your package. Eg: 'caer'
        url = "https://github.com/SchulzR97/rsp-drl",

        keywords=['python', 'Reinforement learning', 'Deep Reinforcement Learning'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
            "Operating System :: POSIX :: Linux",     
        ]
)

==> rsp-drl-0.0.13.tar.gz: rsp-drl-0.0.13/setup.py <==
from setuptools import setup, find_packages

VERSION = '0.0.13' 
DESCRIPTION = 'Some basic functionalities'
with open('README.md') as f:
    LONG_DESCRIPTION = f.read()

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="rsp-drl", 
        version=VERSION,
        author="Robert Schulz",
        author_email="schulzr256@gmail.com",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        long_description_content_type='text/markdown',
        package_dir={"rsp": "rsp"},
        include_package_data=True,
        package_data={
            #"": ["*.png"],
            #"package_data": ["*.*", "*/*.*", "*/*/*.*"],
            "rsp": ["data/*.*", "data/*/*.*"],
            "environment": ["image/*.png"]
        },
        license="MIT",
        packages=find_packages(),
        install_requires=[
            'torch',
            'torchvision',
            'torchaudio',
            'rsp-common',
            'numpy',
            'opencv-python',
            'gym'
        ], # add any additional packages that 
        # needs to be installed along with your package. Eg: 'caer'
        url = "https://github.com/SchulzR97/rsp-drl",

        keywords=['python', 'Reinforement learning', 'Deep Reinforcement Learning'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
            "Operating System :: POSIX :: Linux",     
        ]
)
